% Auto-generated chapter 4 for ibnmajah
% Hadiths in this chapter: 68

\hadithdefcmd{ibnmajah}{735}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا لَيْثُ بْنُ سَعْدٍ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا دَاوُدُ بْنُ عَبْدِ اللَّهِ الْجَعْفَرِيُّ، عَنْ عَبْدِ الْعَزِيزِ بْنِ مُحَمَّدٍ، جَمِيعًا عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ أُسَامَةَ بْنِ الْهَادِ، عَنِ الْوَلِيدِ بْنِ أَبِي الْوَلِيدِ، عَنْ عُثْمَانَ بْنِ عَبْدِ اللَّهِ بْنِ سُرَاقَةَ الْعَدَوِيِّ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ بَنَى مَسْجِدًا يُذْكَرُ فِيهِ اسْمُ اللَّهِ بَنَى اللَّهُ لَهُ بَيْتًا فِي الْجَنَّةِ ‏"‏ ‏.‏\hadithno{735}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Umar bin Khattab said:"I heard the Messenger of Allah say: 'Whoever builds a mosque in which the Name of Allah is mentioned, Allah will build a house for him in Paradise}}
\hadithdefcmd{ibnmajah}{736}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو بَكْرٍ الْحَنَفِيُّ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، عَنْ أَبِيهِ، عَنْ مَحْمُودِ بْنِ لَبِيدٍ، عَنْ عُثْمَانَ بْنِ عَفَّانَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ بَنَى لِلَّهِ مَسْجِدًا بَنَى اللَّهُ لَهُ مِثْلَهُ فِي الْجَنَّةِ ‏"‏ ‏.‏\hadithno{736}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Uthman bin 'Affan said:"I heard the Messenger of Allah say: 'Whoever builds a mosque for the sake of Allah, Allah will build something similar for him in Paradise}}
\hadithdefcmd{ibnmajah}{737}{حَدَّثَنَا الْعَبَّاسُ بْنُ عُثْمَانَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ ابْنِ لَهِيعَةَ، حَدَّثَنِي أَبُو الأَسْوَدِ، عَنْ عُرْوَةَ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ بَنَى لِلَّهِ مَسْجِدًا مِنْ مَالِهِ بَنَى اللَّهُ لَهُ بَيْتًا فِي الْجَنَّةِ ‏"‏ ‏.‏\hadithno{737}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali bin Abu Talib said:"The Messenger of Allah said: 'Whoever builds a mosque for the sake of Allah (from his own wealth), Allah will build a house for him in Paradise}}
\hadithdefcmd{ibnmajah}{738}{حَدَّثَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ إِبْرَاهِيمَ بْنِ نَشِيطٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي حُسَيْنٍ النَّوْفَلِيِّ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ بَنَى مَسْجِدًا لِلَّهِ كَمَفْحَصِ قَطَاةٍ أَوْ أَصْغَرَ بَنَى اللَّهُ لَهُ بَيْتًا فِي الْجَنَّةِ ‏"‏ ‏.‏\hadithno{738}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Jabir bin 'Abdullah that:The Messenger of Allah said: "Whoever builds a mosque for the sake of Allah, like a sparrow's nest for Allah or even smaller, Allah will build for him a house in Paradise}}
\hadithdefcmd{ibnmajah}{739}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُعَاوِيَةَ الْجُمَحِيُّ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى يَتَبَاهَى النَّاسُ فِي الْمَسَاجِدِ ‏"‏ ‏.‏\hadithno{739}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah said: 'The Hour will not begin until the people compete in (building) mosques}}
\hadithdefcmd{ibnmajah}{740}{حَدَّثَنَا جُبَارَةُ بْنُ الْمُغَلِّسِ، حَدَّثَنَا عَبْدُ الْكَرِيمِ بْنُ عَبْدِ الرَّحْمَنِ الْبَجَلِيُّ، عَنْ لَيْثٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَرَاكُمْ سَتُشَرِّفُونَ مَسَاجِدَكُمْ بَعْدِي كَمَا شَرَّفَتِ الْيَهُودُ كَنَائِسَهَا وَكَمَا شَرَّفَتِ النَّصَارَى بِيَعَهَا ‏"‏ ‏.‏\hadithno{740}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Abbas said:The Messenger of Allah said: "I see you building your mosque high after I am gone, just as the Jews built their synagogues high and the Christians built their churches high}}
\hadithdefcmd{ibnmajah}{741}{حَدَّثَنَا جُبَارَةُ بْنُ الْمُغَلِّسِ، حَدَّثَنَا عَبْدُ الْكَرِيمِ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا سَاءَ عَمَلُ قَوْمٍ قَطُّ إِلاَّ زَخْرَفُوا مَسَاجِدَهُمْ ‏"‏ ‏.‏\hadithno{741}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Umar bin Khattab said:The Messenger of Allah said: "No people's deeds ever became evil deeds but they started to adorn their places of worship}}
\hadithdefcmd{ibnmajah}{742}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ أَبِي التَّيَّاحِ الضُّبَعِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ مَوْضِعُ مَسْجِدِ النَّبِيِّ ـ صلى الله عليه وسلم ـ لِبَنِي النَّجَّارِ وَكَانَ فِيهِ نَخْلٌ وَمَقَابِرُ لِلْمُشْرِكِينَ فَقَالَ لَهُمُ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ ثَامِنُونِي بِهِ ‏"‏ ‏.‏ قَالُوا لاَ نَأْخُذُ لَهُ ثَمَنًا أَبَدًا ‏.‏ قَالَ فَكَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يَبْنِيهِ وَهُمْ يُنَاوِلُونَهُ وَالنَّبِيُّ ـ صلى الله عليه وسلم ـ يَقُولُ ‏"‏ أَلاَ إِنَّ الْعَيْشَ عَيْشُ الآخِرَةِ فَاغْفِرْ لِلأَنْصَارِ وَالْمُهَاجِرَةِ ‏"‏ ‏.‏ قَالَ وَكَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يُصَلِّي قَبْلَ أَنْ يَبْنِيَ الْمَسْجِدَ حَيْثُ أَدْرَكَتْهُ الصَّلاَةُ ‏.‏\hadithno{742}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Anas bin Malik said:"The location where the Prophet's Mosque was built belonged to Banu Najjar. In it there were date-palm trees and graves of the idolaters. The Prophet said to them: 'Name its price.' They said: 'We will never take any money for it.' The Prophet built it and they were assisting him, and the Prophet was saying: 'The real life is the life of the Hereafter so forgive the Ansar and the Muhajirah.' Before the mosque was built, the Prophet would perform prayer wherever he was when the time for prayer came}}
\hadithdefcmd{ibnmajah}{743}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو هَمَّامٍ الدَّلاَّلُ، حَدَّثَنَا سَعِيدُ بْنُ السَّائِبِ، عَنْ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ عِيَاضٍ، عَنْ عُثْمَانَ بْنِ أَبِي الْعَاصِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَمَرَهُ أَنْ يَجْعَلَ مَسْجِدَ الطَّائِفِ حَيْثُ كَانَ طَاغِيَتُهُمْ ‏.‏\hadithno{743}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Uthman bin Abul-'As that:The Messenger of Allah commanded him to build the mosque of Ta'if in the place where the Taghuts used to be}}
\hadithdefcmd{ibnmajah}{744}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ، حَدَّثَنَا مُوسَى بْنُ أَعْيَنَ، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، وَسُئِلَ، عَنِ الْحِيطَانِ، تُلْقَى فِيهَا الْعَذِرَاتُ فَقَالَ ‏ "‏ إِذَا سُقِيَتْ مِرَارًا فَصَلُّوا فِيهَا ‏"‏ ‏.‏ يَرْفَعُهُ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{744}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Umar was asked about gardens in which excrement was thrown.:He said: "If it has been watered several times, then perform prayer there," and he attributed that to the Prophet}}
\hadithdefcmd{ibnmajah}{745}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ أَبِيهِ، وَحَمَّادُ بْنُ سَلَمَةَ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الأَرْضُ كُلُّهَا مَسْجِدٌ إِلاَّ الْمَقْبَرَةَ وَالْحَمَّامَ ‏"‏ ‏.‏\hadithno{745}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Sa'eed Khudri said:"The Messenger of Allah said: 'All the earth is a mosque, except for graveyards and Hammam}}
\hadithdefcmd{ibnmajah}{746}{حَدَّثَنَا مُحَمَّدُ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، عَنْ يَحْيَى بْنِ أَيُّوبَ، عَنْ زَيْدِ بْنِ جَبِيرَةَ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يُصَلَّى فِي سَبْعِ مَوَاطِنَ فِي الْمَزْبَلَةِ وَالْمَجْزَرَةِ وَالْمَقْبَرَةِ وَقَارِعَةِ الطَّرِيقِ وَالْحَمَّامِ وَمَعَاطِنِ الإِبِلِ وَفَوْقَ الْكَعْبَةِ ‏.‏\hadithno{746}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Umar said:"Allah's Messenger prohibited prayer from being performed in seven places: The garbage dump, the slaughtering area, the graveyard, the commonly used road, the bathroom, in the area that camels rest at, and above the Ka'bah}}
\hadithdefcmd{ibnmajah}{747}{حَدَّثَنَا عَلِيُّ بْنُ دَاوُدَ، وَمُحَمَّدُ بْنُ أَبِي الْحُسَيْنِ، قَالاَ حَدَّثَنَا أَبُو صَالِحٍ، حَدَّثَنِي اللَّيْثُ، حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ سَبْعُ مَوَاطِنَ لاَ تَجُوزُ فِيهَا الصَّلاَةُ ظَاهِرُ بَيْتِ اللَّهِ وَالْمَقْبَرَةُ وَالْمَزْبَلَةُ وَالْمَجْزَرَةُ وَالْحَمَّامُ وَعَطَنُ الإِبِلِ وَمَحَجَّةُ الطَّرِيقِ ‏"‏ ‏.‏\hadithno{747}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Umar bin Khattab that:The Messenger of Allah said: "There are seven places where it is not permissible to perform the prayer: The top of the House of Allah; graveyards; garbage dumps; slaughterhouses; bathrooms; the area that camels rest, and the main road}}
\hadithdefcmd{ibnmajah}{748}{حَدَّثَنَا يَحْيَى بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرِ بْنِ دِينَارٍ الْحِمْصِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ حِمْيَرَ، حَدَّثَنَا زَيْدُ بْنُ جَبِيرَةَ الأَنْصَارِيُّ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ خِصَالٌ لاَ تَنْبَغِي فِي الْمَسْجِدِ لاَ يُتَّخَذُ طَرِيقًا وَلاَ يُشْهَرُ فِيهِ سِلاَحٌ وَلاَ يُنْبَضُ فِيهِ بِقَوْسٍ وَلاَ يُنْشَرُ فِيهِ نَبْلٌ وَلاَ يُمَرُّ فِيهِ بِلَحْمٍ نِيءٍ وَلاَ يُضْرَبُ فِيهِ حَدٌّ وَلاَ يُقْتَصُّ فِيهِ مِنْ أَحَدٍ وَلاَ يُتَّخَذُ سُوقًا ‏"‏ ‏.‏\hadithno{748}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Umar that:The Messenger of Allah said: "There are things which are not befitting for the mosque: it should not be taken as a thoroughfare; weapons should not be unsheathed in it; bows should not be drawn nor arrows shot in it; no one should pass through it carrying raw meat; no prescribed punishment or retaliatory punishment should be carried out in it; and it should not be used as a marketplace}}
\hadithdefcmd{ibnmajah}{749}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ الْكِنْدِيُّ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الْبَيْعِ وَالاِبْتِيَاعِ وَعَنْ تَنَاشُدِ الأَشْعَارِ فِي الْمَسَاجِدِ ‏.‏\hadithno{749}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Amr bin Shu'aib from his father that his grandfather said:"The Messenger of Allah forbade buying and selling in the mosque, and reciting poetry in the mosque}}
\hadithdefcmd{ibnmajah}{750}{حَدَّثَنَا أَحْمَدُ بْنُ يُوسُفَ السُّلَمِيُّ، حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا الْحَارِثُ بْنُ نَبْهَانَ، حَدَّثَنَا عُتْبَةُ بْنُ يَقْظَانَ، عَنْ أَبِي سَعِيدٍ، عَنْ مَكْحُولٍ، عَنْ وَاثِلَةَ بْنِ الأَسْقَعِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ جَنِّبُوا مَسَاجِدَكُمْ صِبْيَانَكُمْ وَمَجَانِينَكُمْ وَشِرَارَكُمْ وَبَيْعَكُمْ وَخُصُومَاتِكُمْ وَرَفْعَ أَصْوَاتِكُمْ وَإِقَامَةَ حُدُودِكُمْ وَسَلَّ سُيُوفِكُمْ وَاتَّخِذُوا عَلَى أَبْوَابِهَا الْمَطَاهِرَ وَجَمِّرُوهَا فِي الْجُمَعِ ‏"‏ ‏.‏\hadithno{750}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Wathilah bin Asqa' that:The Prophet said: "Keep your infants, your insane and your evil ones away from your mosques. Avoid engaging in transactions and disputes, raising your voices, carrying out your prescribed punishments and unsheathing your swords therein. Make places for purification at their gates, and perfume them with incense on Fridays." (Maudu)}}
\hadithdefcmd{ibnmajah}{751}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، أَنْبَأَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كُنَّا نَنَامُ فِي الْمَسْجِدِ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{751}\hadithgrade{Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:"We used to sleep in the mosque at the time of the Messenger of Allah}}
\hadithdefcmd{ibnmajah}{752}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، حَدَّثَنَا شَيْبَانُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّ يَعِيشَ بْنَ قَيْسِ بْنِ طِخْفَةَ، حَدَّثَهُ عَنْ أَبِيهِ، وَكَانَ، مِنْ أَصْحَابِ الصُّفَّةِ قَالَ قَالَ لَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ انْطَلِقُوا ‏"‏ ‏.‏ فَانْطَلَقْنَا إِلَى بَيْتِ عَائِشَةَ وَأَكَلْنَا وَشَرِبْنَا فَقَالَ لَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنْ شِئْتُمْ نِمْتُمْ هَاهُنَا وَإِنْ شِئْتُمُ انْطَلَقْتُمْ إِلَى الْمَسْجِدِ ‏"‏ ‏.‏ قَالَ فَقُلْنَا بَلْ نَنْطَلِقُ إِلَى الْمَسْجِدِ ‏.‏\hadithno{752}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Ya'ish bin Qais bin Tikhfah narrated that his father, who was one of the people of Suffah, said:"The Messenger of Allah said to us: 'Come with me.' So we went to the house of 'Aishah, where we ate and drank. Then the Messenger of Allah said to us: 'If you want, you can sleep here, or if you want you can go out to the mosque.' We said: 'We will go out to the mosque}}
\hadithdefcmd{ibnmajah}{753}{حَدَّثَنَا عَلِيُّ بْنُ مَيْمُونٍ الرَّقِّيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، ح وَحَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي ذَرٍّ الْغِفَارِيِّ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَىُّ مَسْجِدٍ وُضِعَ أَوَّلُ قَالَ ‏"‏ الْمَسْجِدُ الْحَرَامُ ‏"‏ ‏.‏ قَالَ قُلْتُ ثُمَّ أَىٌّ قَالَ ‏"‏ ثُمَّ الْمَسْجِدُ الأَقْصَى ‏"‏ ‏.‏ قُلْتُ كَمْ بَيْنَهُمَا قَالَ ‏"‏ أَرْبَعُونَ عَامًا ثُمَّ الأَرْضُ لَكَ مُصَلًّى فَصَلِّ حَيْثُ مَا أَدْرَكَتْكَ الصَّلاَةُ ‏"‏ ‏.‏\hadithno{753}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Dharr Al-Ghifari said:"I said: 'O Messenger of Allah! Which mosque was built first?' He said: 'Al-Masjid Al-Haram (in Makkah).' I said: 'Then which?' He said: 'then Al-Masjid Al-Aqsa (in Jerusalem).' I said: 'How many years between them?' He said: 'Forty years, but the whole earth is a mosque for you, so pray wherever you are when the time for prayer comes}}
\hadithdefcmd{ibnmajah}{754}{حَدَّثَنَا أَبُو مَرْوَانَ، مُحَمَّدُ بْنُ عُثْمَانَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ مَحْمُودِ بْنِ الرَّبِيعِ الأَنْصَارِيِّ، - وَكَانَ قَدْ عَقَلَ مَجَّةً مَجَّهَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مِنْ دَلْوٍ فِي بِئْرٍ لَهُمْ - عَنْ عِتْبَانَ بْنِ مَالِكٍ السَّالِمِيِّ - وَكَانَ إِمَامَ قَوْمِهِ بَنِي سَالِمٍ وَكَانَ شَهِدَ بَدْرًا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ - قَالَ جِئْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي قَدْ أَنْكَرْتُ مِنْ بَصَرِي وَإِنَّ السَّيْلَ يَأْتِينِي فَيَحُولُ بَيْنِي وَبَيْنَ مَسْجِدِ قَوْمِي وَيَشُقُّ عَلَىَّ اجْتِيَازُهُ فَإِنْ رَأَيْتَ أَنْ تَأْتِيَنِي فَتُصَلِّيَ فِي بَيْتِي مَكَانًا أَتَّخِذُهُ مُصَلًّى فَافْعَلْ ‏.‏ قَالَ ‏"‏ أَفْعَلُ ‏"‏ ‏.‏ فَغَدَا عَلَىَّ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَأَبُو بَكْرٍ بَعْدَ مَا اشْتَدَّ النَّهَارُ وَاسْتَأْذَنَ فَأَذِنْتُ لَهُ وَلَمْ يَجْلِسْ حَتَّى قَالَ ‏"‏ أَيْنَ تُحِبُّ أَنْ أُصَلِّيَ لَكَ مِنْ بَيْتِكَ ‏"‏ ‏.‏ فَأَشَرْتُ لَهُ إِلَى الْمَكَانِ الَّذِي أُحِبُّ أَنْ أُصَلِّيَ فِيهِ فَقَامَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَصَفَفْنَا خَلْفَهُ فَصَلَّى بِنَا رَكْعَتَيْنِ ثُمَّ احْتَبَسْتُهُ عَلَى خَزِيرَةٍ تُصْنَعُ لَهُمْ ‏.‏\hadithno{754}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Mahmud bin Rabi' Al-Ansari, who remembered that the Messenger of Allah spat a mouthful of water from a bucket into a well that belonged to them, narrated that :'Itban bin Malik As-Salimi who was the chief of his people Banu Salim and had participated in (the battle of) Badr with the Messenger of Allah said: "I came to the Messenger of Allah and said: 'O Messenger of Allah, my sight is failing and the flood comes and prevents me from reaching the mosque of my people, and it is too hard for me to cross the water. Do you think you could come and perform prayer in my house in a place which I can then take as a place of prayer?' He said: 'I will do that.' The following day, the Messenger of Allah and Abu Bakr came, when the heat of the day had grown intense. He asked permission to enter, and I gave him permission. He did not sit down until he said: 'Where would you like me to perform prayer for you in your house?' I showed him the place where I wanted him to pray, so the Messenger of Allah stood and we lined up behind him, and he led us in praying two Rak'ah (units). Then I asked him to stay and eat some Khazirah that had been prepared for them}}
\hadithdefcmd{ibnmajah}{755}{حَدَّثَنَا يَحْيَى بْنُ الْفَضْلِ الْمُقْرِي، حَدَّثَنَا أَبُو عَامِرٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ عَاصِمٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَجُلاً، مِنَ الأَنْصَارِ أَرْسَلَ إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ تَعَالَ فَخُطَّ لِي مَسْجِدًا فِي دَارِي أُصَلِّي فِيهِ وَذَلِكَ بَعْدَ مَا عَمِيَ فَجَاءَ فَفَعَلَ ‏.‏\hadithno{755}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that:A man among the Ansar sent word to the Messenger of Allah saying: "Come and designate a place in my house where I can perform prayer,' that was after he had become blind. So he went and did that}}
\hadithdefcmd{ibnmajah}{756}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنِ ابْنِ عَوْنٍ، عَنْ أَنَسِ بْنِ سِيرِينَ، عَنْ عَبْدِ الْحَمِيدِ بْنِ الْمُنْذِرِ بْنِ الْجَارُودِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ صَنَعَ بَعْضُ عُمُومَتِي لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ طَعَامًا فَقَالَ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ إِنِّي أُحِبُّ أَنْ تَأْكُلَ فِي بَيْتِي وَتُصَلِّيَ فِيهِ ‏.‏ قَالَ فَأَتَاهُ وَفِي الْبَيْتِ فَحْلٌ مِنْ هَذِهِ الْفُحُولِ فَأَمَرَ بِنَاحِيَةٍ مِنْهُ فَكُنِسَ وَرُشَّ فَصَلَّى وَصَلَّيْنَا مَعَهُ ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ بْنُ مَاجَهْ الْفَحْلُ هُوَ الْحَصِيرُ الَّذِي قَدِ اسْوَدَّ ‏.‏\hadithno{756}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Anas bin Malik said:"One of my paternal uncles made some food for the Prophet and said to the Prophet: 'I would like you to eat and perform prayer in my house.' So he went to him, and in his house there was one of these Fahl. He ordered that a corner be swept and water sprinkled in it, then he performed prayer and we prayed with him.'" (Sahih)Abu 'Abdullah bin Majah said: A Fahl is a mat that has become black (through use)}}
\hadithdefcmd{ibnmajah}{757}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سُلَيْمَانَ بْنِ أَبِي الْجَوْنِ، حَدَّثَنَا مُحَمَّدُ بْنُ صَالِحٍ الْمَدَنِيُّ، حَدَّثَنَا مُسْلِمُ بْنُ أَبِي مَرْيَمَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ أَخْرَجَ أَذًى مِنَ الْمَسْجِدِ بَنَى اللَّهُ لَهُ بَيْتًا فِي الْجَنَّةِ ‏"‏ ‏.‏\hadithno{757}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"The Messenger of Allah said: 'Whoever removes something harmful from the mosque, Allah will build for him a house in Paradise}}
\hadithdefcmd{ibnmajah}{758}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ بِشْرِ بْنِ الْحَكَمِ، وَأَحْمَدُ بْنُ الأَزْهَرِ، قَالاَ حَدَّثَنَا مَالِكُ بْنُ سُعَيْرٍ، أَنْبَأَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَمَرَ بِالْمَسَاجِدِ أَنْ تُبْنَى فِي الدُّورِ وَأَنْ تُطَهَّرَ وَتُطَيَّبَ ‏.‏\hadithno{758}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Aishah that:The Messenger of Allah commanded that mosque to be built in (Ad-Dur) villages, and that they be purified and perfumed}}
\hadithdefcmd{ibnmajah}{759}{حَدَّثَنَا رِزْقُ اللَّهِ بْنُ مُوسَى، حَدَّثَنَا يَعْقُوبُ بْنُ إِسْحَاقَ الْحَضْرَمِيُّ، حَدَّثَنَا زَائِدَةُ بْنُ قُدَامَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ أَمَرَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ تُتَّخَذَ الْمَسَاجِدُ فِي الدُّورِ وَأَنْ تُطَهَّرَ وَتُطَيَّبَ ‏.‏\hadithno{759}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that:The Messenger of Allah commanded that places of prayer be established in villages, and that they be purified and perfumed}}
\hadithdefcmd{ibnmajah}{760}{حَدَّثَنَا أَحْمَدُ بْنُ سِنَانٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ خَالِدِ بْنِ إِيَاسٍ، عَنْ يَحْيَى بْنِ عَبْدِ الرَّحْمَنِ بْنِ حَاطِبٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ أَوَّلُ مَنْ أَسْرَجَ فِي الْمَسَاجِدِ تَمِيمٌ الدَّارِيُّ ‏.‏\hadithno{760}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"The first person who put lamps in the mosque was Tamim Ad-Dari}}
\hadithdefcmd{ibnmajah}{761}{حَدَّثَنَا مُحَمَّدُ بْنُ عُثْمَانَ الْعُثْمَانِيُّ أَبُو مَرْوَانَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ أَبِي هُرَيْرَةَ، وَأَبِي، سَعِيدٍ الْخُدْرِيِّ أَنَّهُمَا أَخْبَرَاهُ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ رَأَى نُخَامَةً فِي جِدَارِ الْمَسْجِدِ فَتَنَاوَلَ حَصَاةً فَحَكَّهَا ثُمَّ قَالَ ‏ "‏ إِذَا تَنَخَّمَ أَحَدُكُمْ فَلاَ يَتَنَخَّمَنَّ قِبَلَ وَجْهِهِ وَلاَ عَنْ يَمِينِهِ وَلْيَبْزُقْ عَنْ شِمَالِهِ أَوْ تَحْتَ قَدَمِهِ الْيُسْرَى ‏"‏ ‏.‏\hadithno{761}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It is narrated from Abu Hurairah and Abu Sa'eed Al-Khudri that:The Messenger of Allah saw some sputum on the wall of the mosque. He picked up a stone and scraped it off, then he said, "If anyone of you needs to spit, he should not spit in fro not of him or to his right; let him spit to his right; let him spit to his left or under his left foot}}
\hadithdefcmd{ibnmajah}{762}{حَدَّثَنَا مُحَمَّدُ بْنُ طَرِيفٍ، حَدَّثَنَا عَائِذُ بْنُ حَبِيبٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ رَأَى نُخَامَةً فِي قِبْلَةِ الْمَسْجِدِ فَغَضِبَ حَتَّى احْمَرَّ وَجْهُهُ فَجَاءَتْهُ امْرَأَةٌ مِنَ الأَنْصَارِ فَحَكَّتْهَا وَجَعَلَتْ مَكَانَهَا خَلُوقًا فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا أَحْسَنَ هَذَا ‏"‏ ‏.‏\hadithno{762}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Anas that:The Prophet saw some sputum in the prayer direction of the mosque and he became so angry that his face turned red. Then a woman from among the Ansar came and scraped it off, and put some Khaluq on that spot. The Messenger of Allah said: "How good this is}}
\hadithdefcmd{ibnmajah}{763}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ الْمِصْرِيُّ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ رَأَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ نُخَامَةً فِي قِبْلَةِ الْمَسْجِدِ وَهُوَ يُصَلِّي بَيْنَ يَدَىِ النَّاسِ فَحَتَّهَا ثُمَّ قَالَ حِينَ انْصَرَفَ مِنَ الصَّلاَةِ ‏ "‏ إِنَّ أَحَدَكُمْ إِذَا كَانَ فِي الصَّلاَةِ كَانَ اللَّهُ قِبَلَ وَجْهِهِ فَلاَ يَتَنَخَّمَنَّ أَحَدُكُمْ قِبَلَ وَجْهِهِ فِي الصَّلاَةِ ‏"‏ ‏.‏\hadithno{763}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that 'Abdullah bin 'Umar said:"The Messenger of Allah saw some sputum in the prayer direction of the mosque, when he was praying in front of the people. He scratched it off, then when the prayer was over, he said: 'When anyone of you is performing prayer, Allah is before him, so none of you should spit toward the front while praying}}
\hadithdefcmd{ibnmajah}{764}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ حَكَّ بُزَاقًا فِي قِبْلَةِ الْمَسْجِدِ ‏.‏\hadithno{764}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Aishah that:The Prophet scratched some spittle from the prayer direction of the mosque}}
\hadithdefcmd{ibnmajah}{765}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ أَبِي سِنَانٍ، سَعِيدِ بْنِ سِنَانٍ عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ صَلَّى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ رَجُلٌ مَنْ دَعَا إِلَى الْجَمَلِ الأَحْمَرِ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ وَجَدْتَهُ إِنَّمَا بُنِيَتِ الْمَسَاجِدُ لِمَا بُنِيَتْ لَهُ ‏"‏ ‏.‏\hadithno{765}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Sulaiman bin Burdah that his father said:"The Messenger of Allah performed prayer, then a man said: 'Who was looking for the red camel?' The Prophet said: 'May you not find it! The mosques were built for that for which they were built}}
\hadithdefcmd{ibnmajah}{766}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا ابْنُ لَهِيعَةَ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، جَمِيعًا عَنِ ابْنِ عَجْلاَنَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ نَهَى عَنْ إِنْشَادِ الضَّالَّةِ فِي الْمَسْجِدِ ‏.‏\hadithno{766}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Amr bin Shu'aib from his father, from his grandfather that:The Messenger of Allah forbade making lost-and-found announcements in the mosque}}
\hadithdefcmd{ibnmajah}{767}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي حَيْوَةُ بْنُ شُرَيْحٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ الأَسَدِيِّ أَبِي الأَسْوَدِ، عَنْ أَبِي عَبْدِ اللَّهِ، مَوْلَى شَدَّادِ بْنِ الْهَادِ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ سَمِعَ رَجُلاً يَنْشُدُ ضَالَّةً فِي الْمَسْجِدِ فَلْيَقُلْ لاَ رَدَّ اللَّهُ عَلَيْكَ فَإِنَّ الْمَسَاجِدَ لَمْ تُبْنَ لِهَذَا ‏"‏ ‏.‏\hadithno{767}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu 'Abdullah, the freed slave of Shaddad bin Had that:He heard Abu Hurairah say: "I heard the Messenger of Allah say: 'Whoever hears a man making a lost-and-found announcement in the mosque, let him say: "May Allah not return it to you!" For the mosques were not built for that}}
\hadithdefcmd{ibnmajah}{768}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، ح وَحَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالاَ حَدَّثَنَا هِشَامُ بْنُ حَسَّانَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنْ لَمْ تَجِدُوا إِلاَّ مَرَابِضَ الْغَنَمِ وَأَعْطَانَ الإِبِلِ فَصَلُّوا فِي مَرَابِضِ الْغَنَمِ وَلاَ تُصَلُّوا فِي أَعْطَانِ الإِبِلِ ‏"‏ ‏.‏\hadithno{768}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:The Messenger of Allah said: "If you cannot find anywhere (for prayer) except sheep's resting-places and camels' resting-places, then perform prayer in the sheep's resting-places and do not perform prayer in the camels' resting-places}}
\hadithdefcmd{ibnmajah}{769}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا هُشَيْمٌ، عَنْ يُونُسَ، عَنِ الْحَسَنِ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ الْمُزَنِيِّ، قَالَ قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ صَلُّوا فِي مَرَابِضِ الْغَنَمِ وَلاَ تُصَلُّوا فِي أَعْطَانِ الإِبِلِ فَإِنَّهَا خُلِقَتْ مِنَ الشَّيَاطِينِ ‏"‏ ‏.‏\hadithno{769}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah bin Mughaffal Al-Muzani said:"The Prophet said: 'Perform prayer in the sheep's resting-places and do not perform prayer in the camels' resting-places, for they were created from the devils}}
\hadithdefcmd{ibnmajah}{770}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ رَبِيعِ بْنِ سَبْرَةَ بْنِ مَعْبَدٍ الْجُهَنِيُّ، أَخْبَرَنِي أَبِي، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ يُصَلَّى فِي أَعْطَانِ الإِبِلِ وَيُصَلَّى فِي مُرَاحِ الْغَنَمِ ‏"‏ ‏.‏\hadithno{770}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdul-Malik bin Rabi' bin Sabrah bin Ma'bad Al-Juhani said:"My father told me, from his father that the Messenger of Allah said: 'Do not perform prayer in the camels' resting-places, and perform prayer in the sheep's resting-places}}
\hadithdefcmd{ibnmajah}{771}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، وَأَبُو مُعَاوِيَةَ عَنْ لَيْثٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَسَنِ، عَنْ أُمِّهِ، عَنْ فَاطِمَةَ بِنْتِ رَسُولِ اللَّهِ، ـ صلى الله عليه وسلم ـ قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا دَخَلَ الْمَسْجِدَ يَقُولُ ‏"‏ بِسْمِ اللَّهِ وَالسَّلاَمُ عَلَى رَسُولِ اللَّهِ اللَّهُمَّ اغْفِرْ لِي ذُنُوبِي وَافْتَحْ لِي أَبْوَابَ رَحْمَتِكَ ‏"‏ ‏.‏ وَإِذَا خَرَجَ قَالَ ‏"‏ بِسْمِ اللَّهِ وَالسَّلاَمُ عَلَى رَسُولِ اللَّهِ اللَّهُمَّ اغْفِرْ لِي ذُنُوبِي وَافْتَحْ لِي أَبْوَابَ فَضْلِكَ ‏"‏ ‏.‏\hadithno{771}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Fatimah the daughter of the Messenger of Allah said:"Whenever the Messenger of Allah entered the mosque he would say: 'Bismillah, was-salamu 'ala Rasulillah, Allahummagh-firli dhunubi waftah li abwaba rahmatika. (In the Name of Allah, and peace be upon the Messenger of Allah. O Allah, forgive me my sins and open to me the gates of Your mercy).' When he left he would say: 'Bismillah, was-salamu 'ala Rasulillah, Allahummagh-firli dhunubi waftah li abwaba fadlika. (In the Name of Allah, and peace be upon the Messenger of Allah. O Allah, forgive me my sins and open to me the gates of Your bounty)}}
\hadithdefcmd{ibnmajah}{772}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرِ بْنِ دِينَارٍ الْحِمْصِيُّ، وَعَبْدُ الْوَهَّابِ بْنُ الضَّحَّاكِ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ عُمَارَةَ بْنِ غَزِيَّةَ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ الْمَلِكِ بْنِ سَعِيدِ بْنِ سُوَيْدٍ الأَنْصَارِيِّ، عَنْ أَبِي حُمَيْدٍ السَّاعِدِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا دَخَلَ أَحَدُكُمُ الْمَسْجِدَ فَلْيُسَلِّمْ عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ ثُمَّ لْيَقُلِ اللَّهُمَّ افْتَحْ لِي أَبْوَابَ رَحْمَتِكَ ‏.‏ وَإِذَا خَرَجَ فَلْيَقُلِ اللَّهُمَّ إِنِّي أَسْأَلُكَ مِنْ فَضْلِكَ ‏"‏ ‏.‏\hadithno{772}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Humaid As-Sa'idi said:"The Messenger of Allah said: 'When anyone of you enters the mosque, let him send peace upon the prophet, then let him say: "Allahummaftah li abwaba rahmatika (O Allah, open to me the gates of Your mercy)." And when he leaves, let him say: "Allahumma inni as'aluka min fadlika. (O Allah, I ask of you from Your bounty)}}
\hadithdefcmd{ibnmajah}{773}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو بَكْرٍ الْحَنَفِيُّ، حَدَّثَنَا الضَّحَّاكُ بْنُ عُثْمَانَ، حَدَّثَنِي سَعِيدٌ الْمَقْبُرِيُّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا دَخَلَ أَحَدُكُمُ الْمَسْجِدَ فَلْيُسَلِّمْ عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ وَلْيَقُلِ اللَّهُمَّ افْتَحْ لِي أَبْوَابَ رَحْمَتِكَ وَإِذَا خَرَجَ فَلْيُسَلِّمْ عَلَى النَّبِيِّ وَلْيَقُلِ اللَّهُمَّ اعْصِمْنِي مِنَ الشَّيْطَانِ الرَّجِيمِ ‏"‏ ‏.‏\hadithno{773}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that:The Mesenger of Allah said: "When anyone of enters the mosque, let him send peace upon the Prophet, then let him say: 'Allahumma aftahli abwaba rahmatik (O Allah, open to me the gates of Your mercy).' And when he leaves, let him send peace upon the Prophet and say: 'Allahumma- simni minash-shaitanir-rajim (O Allah, protect me from the accursed Shaitan)}}
\hadithdefcmd{ibnmajah}{774}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا تَوَضَّأَ أَحَدُكُمْ فَأَحْسَنَ الْوُضُوءَ ثُمَّ أَتَى الْمَسْجِدَ لاَ يَنْهَزُهُ إِلاَّ الصَّلاَةُ لاَ يُرِيدُ إِلاَّ الصَّلاَةَ لَمْ يَخْطُ خَطْوَةً إِلاَّ رَفَعَهُ اللَّهُ بِهَا دَرَجَةً وَحَطَّ عَنْهُ بِهَا خَطِيئَةً حَتَّى يَدْخُلَ الْمَسْجِدَ فَإِذَا دَخَلَ الْمَسْجِدَ كَانَ فِي صَلاَةٍ مَا كَانَتِ الصَّلاَةُ تَحْبِسُهُ ‏"‏ ‏.‏\hadithno{774}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'When one of you performs ablution and does it well, then he comes to the mosque with no other motive but prayer and not seeking anything other than the prayer, he does not take one step but Allah raises him in status one degree thereby, and takes away one of his sins, until he enters the mosque. When he enters the mosque he is in a state of prayer so long as he is waiting for the prayer}}
\hadithdefcmd{ibnmajah}{775}{حَدَّثَنَا أَبُو مَرْوَانَ الْعُثْمَانِيُّ، مُحَمَّدُ بْنُ عُثْمَانَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا أُقِيمَتِ الصَّلاَةُ فَلاَ تَأْتُوهَا وَأَنْتُمْ تَسْعَوْنَ وَأْتُوهَا تَمْشُونَ وَعَلَيْكُمُ السَّكِينَةُ فَمَا أَدْرَكْتُمْ فَصَلُّوا وَمَا فَاتَكُمْ فَأَتِمُّوا ‏"‏ ‏.‏\hadithno{775}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah said: "When the Iqamah is called for the prayer, do not come running. Come walking with tranquility. Whatever you catch up with, pray, and whatever you miss, complete it}}
\hadithdefcmd{ibnmajah}{776}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، حَدَّثَنَا زُهَيْرُ بْنُ مُحَمَّدٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏"‏ أَلاَ أَدُلُّكُمْ عَلَى مَا يُكَفِّرُ اللَّهُ بِهِ الْخَطَايَا وَيَزِيدُ بِهِ فِي الْحَسَنَاتِ ‏"‏ ‏.‏ قَالُوا بَلَى يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ إِسْبَاغُ الْوُضُوءِ عِنْدَ الْمَكَارِهِ وَكَثْرَةُ الْخُطَى إِلَى الْمَسَاجِدِ وَانْتِظَارُ الصَّلاَةِ بَعْدَ الصَّلاَةِ ‏"‏ ‏.‏\hadithno{776}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Sa'eed Al-Khudri that :He heard the Messenger of Allah say: 'Shall I not tell you of something by means of which Allah expiates for sins and increases good deeds?' They said: 'Yes, O Messenger of Allah.' He said: 'Performing ablution properly despite difficulties, increasing the number of steps one takes towards the mosque and waiting for the next prayer after prayer}}
\hadithdefcmd{ibnmajah}{777}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ إِبْرَاهِيمَ الْهَجَرِيِّ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، قَالَ مَنْ سَرَّهُ أَنْ يَلْقَى اللَّهَ غَدًا مُسْلِمًا فَلْيُحَافِظْ عَلَى هَؤُلاَءِ الصَّلَوَاتِ الْخَمْسِ حَيْثُ يُنَادَى بِهِنَّ فَإِنَّهُنَّ مِنْ سُنَنِ الْهُدَى وَإِنَّ اللَّهَ شَرَعَ لِنَبِيِّكُمْ ـ صلى الله عليه وسلم ـ سُنَنَ الْهُدَى وَلَعَمْرِي لَوْ أَنَّ كُلَّكُمْ صَلَّى فِي بَيْتِهِ لَتَرَكْتُمْ سُنَّةَ نَبِيِّكُمْ وَلَوْ تَرَكْتُمْ سُنَّةَ نَبِيِّكُمْ لَضَلَلْتُمْ وَلَقَدْ رَأَيْتُنَا وَمَا يَتَخَلَّفُ عَنْهَا إِلاَّ مُنَافِقٌ مَعْلُومُ النِّفَاقِ وَلَقَدْ رَأَيْتُ الرَّجُلَ يُهَادَى بَيْنَ الرَّجُلَيْنِ حَتَّى يَدْخُلَ فِي الصَّفِّ وَمَا مِنْ رَجُلٍ يَتَطَهَّرُ فَيُحْسِنُ الطُّهُورَ فَيَعْمِدُ إِلَى الْمَسْجِدِ فَيُصَلِّي فِيهِ فَمَا يَخْطُو خَطْوَةً إِلاَّ رَفَعَ اللَّهُ لَهُ بِهَا دَرَجَةً وَحَطَّ عَنْهُ بِهَا خَطِيئَةً ‏.‏\hadithno{777}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah said:"Whoever would like to meet Allah tomorrow (i.e. on the Day of Judgment) as a Muslim, let him preserve these five (daily) prayer when the call for them is given, for they are part of the ways of guidance, and Allah prescribed the ways of guidance to your Prophet. By Allah, if each of you prays in his house, you will have abandoned the Sunnah of your Prophet, and if you abandon the Sunnah of your Prophet you will go astray. I remember when no one stayed behind from the prayer except a hypocrite who was known for his hypocrisy. I have a man coming supported by two others, until he joined the row (of worshippers). There is no man who purifies himself and does it well, and comes to the mosque and prays there, but for every step that he takes, Allah raises him in status one degree thereby, and takes away one of his sins}}
\hadithdefcmd{ibnmajah}{778}{حَدَّثَنَا مُحَمَّدُ بْنُ سَعِيدِ بْنِ يَزِيدَ بْنِ إِبْرَاهِيمَ التُّسْتَرِيُّ، حَدَّثَنَا الْفَضْلُ بْنُ الْمُوَفَّقِ أَبُو الْجَهْمِ، حَدَّثَنَا فُضَيْلُ بْنُ مَرْزُوقٍ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ خَرَجَ مِنْ بَيْتِهِ إِلَى الصَّلاَةِ فَقَالَ اللَّهُمَّ إِنِّي أَسْأَلُكَ بِحَقِّ السَّائِلِينَ عَلَيْكَ وَأَسْأَلُكَ بِحَقِّ مَمْشَاىَ هَذَا فَإِنِّي لَمْ أَخْرُجْ أَشَرًا وَلاَ بَطَرًا وَلاَ رِيَاءً وَلاَ سُمْعَةً وَخَرَجْتُ اتِّقَاءَ سُخْطِكَ وَابْتِغَاءَ مَرْضَاتِكَ فَأَسْأَلُكَ أَنْ تُعِيذَنِي مِنَ النَّارِ وَأَنْ تَغْفِرَ لِي ذُنُوبِي إِنَّهُ لاَ يَغْفِرُ الذُّنُوبَ إِلاَّ أَنْتَ - أَقْبَلَ اللَّهُ عَلَيْهِ بِوَجْهِهِ وَاسْتَغْفَرَ لَهُ سَبْعُونَ أَلْفَ مَلَكٍ ‏"‏ ‏.‏\hadithno{778}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"The Messenger of Allah said: 'Whoever leaves his house for the prayer and says: 'Allahumma inni asa'luka bi-haqqis-sa'ilina 'alaika, wa as'aluka bi-haqqi mamshaya hadha, fa inni lam akhruj asharan wa la batran, wa la riya'an, wa la sum'atan, wa kharajtu-ttiqa'a sukhtika wabtigha'a mardatika, fa as'aluka an tu'idhani minan-nari wa an taghfira li dhunubi, Innahu la yaghfirudh-dhunuba illa Anta. (O Allah, I ask You by the right that those who ask of You have over You, and I ask by virtue of this walking of mine, for I am not going out because of pride or vanity, or to show off or make a reputation, rather I am going out because I fear Your wrath and seek Your pleasure. So I ask You to protect me from the Fire and to forgive me my sins, for no one can forgive sins except You),' Allah will turn His Face towards him and seventy thousand angels will pray for his forgiveness}}
\hadithdefcmd{ibnmajah}{779}{حَدَّثَنَا رَاشِدُ بْنُ سَعِيدِ بْنِ رَاشِدٍ الرَّمْلِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنْ أَبِي رَافِعٍ، إِسْمَاعِيلَ بْنِ رَافِعٍ عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرٍ عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْمَشَّاءُونَ إِلَى الْمَسَاجِدِ فِي الظُّلَمِ أُولَئِكَ الْخَوَّاضُونَ فِي رَحْمَةِ اللَّهِ ‏"‏ ‏.‏\hadithno{779}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Those who walk to the mosque in the dark are those who are diving into the mercy of Allah}}
\hadithdefcmd{ibnmajah}{780}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُحَمَّدٍ الْحَلَبِيُّ، حَدَّثَنَا يَحْيَى بْنُ الْحَارِثِ الشِّيرَازِيُّ، حَدَّثَنَا زُهَيْرُ بْنُ مُحَمَّدٍ التَّمِيمِيُّ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لِيَبْشَرِ الْمَشَّاءُونَ فِي الظُّلَمِ إِلَى الْمَسَاجِدِ بِنُورٍ تَامٍّ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{780}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Sahl bin Sa'd As-Sa'idi said:"The Messenger of Allah said: 'Give glad tidings, to those who walk to the mosques in the dark, of perfect light on the Day of Resurrection}}
\hadithdefcmd{ibnmajah}{781}{حَدَّثَنَا مَجْزَأَةُ بْنُ سُفْيَانَ بْنِ أَسِيدٍ، مَوْلَى ثَابِتٍ الْبُنَانِيِّ حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الصَّائِغُ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ بَشِّرِ الْمَشَّائِينَ فِي الظُّلَمِ إِلَى الْمَسَاجِدِ بِالنُّورِ التَّامِّ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{781}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah said: 'Give glad tidings to those who walk to the mosques in the dark, of perfect light on the Day of Resurrection}}
\hadithdefcmd{ibnmajah}{782}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ مِهْرَانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَعْدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الأَبْعَدُ فَالأَبْعَدُ مِنَ الْمَسْجِدِ أَعْظَمُ أَجْرًا ‏"‏ ‏.‏\hadithno{782}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'The greater the distance from the mosque, the greater the reward}}
\hadithdefcmd{ibnmajah}{783}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، حَدَّثَنَا عَبَّادُ بْنُ عَبَّادٍ الْمُهَلَّبِيُّ، حَدَّثَنَا عَاصِمٌ الأَحْوَلُ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ كَانَ رَجُلٌ مِنَ الأَنْصَارِ بَيْتُهُ أَقْصَى بَيْتٍ بِالْمَدِينَةِ وَكَانَ لاَ تُخْطِئُهُ الصَّلاَةُ مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ قَالَ فَتَوَجَّعْتُ لَهُ فَقُلْتُ يَا فُلاَنُ لَوْ أَنَّكَ اشْتَرَيْتَ حِمَارًا يَقِيكَ الرَّمَضَ وَيَرْفَعُكَ مِنَ الْوَقَعِ وَيَقِيكَ هَوَامَّ الأَرْضِ ‏.‏ فَقَالَ وَاللَّهِ مَا أُحِبُّ أَنَّ بَيْتِي بِطُنُبِ بَيْتِ مُحَمَّدٍ ـ صلى الله عليه وسلم ـ ‏.‏ قَالَ فَحَمَلْتُ بِهِ حِمْلاً حَتَّى أَتَيْتُ بَيْتَ النَّبِيِّ ـ صلى الله عليه وسلم ـ فَذَكَرْتُ ذَلِكَ لَهُ فَدَعَاهُ فَسَأَلَهُ فَذَكَرَ لَهُ مِثْلَ ذَلِكَ وَذَكَرَ أَنَّهُ يَرْجُو فِي أَثَرِهِ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ لَكَ مَا احْتَسَبْتَ ‏"‏ ‏.‏\hadithno{783}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ubayy bin Ka'b said:"There was a man among the Ansar whose house was the furthest house in Al-Madinah, yet he never missed prayer with the Messenger of Allah. I felt sorry for him and said: 'O so-and-so, why do you not buy a donkey to spare yourself the heat of the scorching sand, to carry over the stony ground, and to keep you away from the vermin on the ground?' He said: 'By Allah! I do not want to live so close to Muhammed.' This troubled me until I came to the house of the Prophet and mentioned that to him. He called (the man) and asked him, and he said something similar, and said that he was hoping for the reward for his steps. The Messenger of Allah said, 'You will have that (reward) that you sought}}
\hadithdefcmd{ibnmajah}{784}{حَدَّثَنَا أَبُو مُوسَى، مُحَمَّدُ بْنُ الْمُثَنَّى حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ أَرَادَتْ بَنُو سَلِمَةَ أَنْ يَتَحَوَّلُوا، مِنْ دِيَارِهِمْ إِلَى قُرْبِ الْمَسْجِدِ فَكَرِهَ النَّبِيُّ ـ صلى الله عليه وسلم ـ أَنْ يُعْرُوا الْمَدِينَةَ فَقَالَ ‏ "‏ يَا بَنِي سَلِمَةَ أَلاَ تَحْتَسِبُونَ آثَارَكُمْ ‏"‏ ‏.‏ فَأَقَامُوا ‏.‏\hadithno{784}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Anas said:"Banu Salimah wanted to move from their homes to somewhere near the mosque, but the Prophet did not want the outskirts of Al-madinah to be left vacant, so he said: 'O Banu Salimah, do you not hope for the reward of your footsteps?' So they stayed (where they were)}}
\hadithdefcmd{ibnmajah}{785}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَتِ الأَنْصَارُ بَعِيدَةً مَنَازِلُهُمْ مِنَ الْمَسْجِدِ فَأَرَادُوا أَنْ يَقْتَرِبُوا فَنَزَلَتْ ‏\{وَنَكْتُبُ مَا قَدَّمُوا وَآثَارَهُمْ\}‏ قَالَ فَثَبَتُوا ‏.‏\hadithno{785}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Abbas said:"The houses of the Ansar were far from the mosque and they wanted to move closer. Then the following Verse was revealed: 'We record that which they send before (them), and their traces.'" [Ya-Sin: 12] He said: So they remained (where they were)}}
\hadithdefcmd{ibnmajah}{786}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ صَلاَةُ الرَّجُلِ فِي جَمَاعَةٍ تَزِيدُ عَلَى صَلاَتِهِ فِي بَيْتِهِ وَصَلاَتِهِ فِي سُوقِهِ بِضْعًا وَعِشْرِينَ دَرَجَةً ‏"‏ ‏.‏\hadithno{786}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'A man's prayer in congregation is twenty-some levels higher than his prayer in his house or in the marketplace}}
\hadithdefcmd{ibnmajah}{787}{حَدَّثَنَا أَبُو مَرْوَانَ، مُحَمَّدُ بْنُ عُثْمَانَ الْعُثْمَانِيُّ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ فَضْلُ الْجَمَاعَةِ عَلَى صَلاَةِ أَحَدِكُمْ وَحْدَهُ خَمْسٌ وَعِشْرُونَ جُزْءًا ‏"‏ ‏.‏\hadithno{787}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah said: "The prayer in congregation is twenty-five times more virtuous than the prayer of anyone of you on his own}}
\hadithdefcmd{ibnmajah}{788}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ هِلاَلِ بْنِ مَيْمُونٍ، عَنْ عَطَاءِ بْنِ يَزِيدَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ صَلاَةُ الرَّجُلِ فِي جَمَاعَةٍ تَزِيدُ عَلَى صَلاَتِهِ فِي بَيْتِهِ خَمْسًا وَعِشْرِينَ دَرَجَةً ‏"‏ ‏.‏\hadithno{788}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"The Messenger of Allah said: 'the prayer of a man in congregation is twenty-five levels higher than his prayer in his home}}
\hadithdefcmd{ibnmajah}{789}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عُمَرَ، رُسْتَهْ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ صَلاَةُ الرَّجُلِ فِي جَمَاعَةٍ تَفْضُلُ عَلَى صَلاَةِ الرَّجُلِ وَحْدَهُ بِسَبْعٍ وَعِشْرِينَ دَرَجَةً ‏"‏ ‏.‏\hadithno{789}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah said: 'The prayer of a man in congregation is twenty-seven levels more virtuous than a man's prayer on his own}}
\hadithdefcmd{ibnmajah}{790}{حَدَّثَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، حَدَّثَنَا أَبُو بَكْرٍ الْحَنَفِيُّ، حَدَّثَنَا يُونُسُ بْنُ أَبِي إِسْحَاقَ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَصِيرٍ، عَنْ أَبِيهِ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ صَلاَةُ الرَّجُلِ فِي جَمَاعَةٍ تَزِيدُ عَلَى صَلاَةِ الرَّجُلِ وَحْدَهُ أَرْبَعًا وَعِشْرِينَ أَوْ خَمْسًا وَعِشْرِينَ دَرَجَةً ‏"‏ ‏.‏\hadithno{790}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ubayy bin Ka'b said:"The Messenger of Allah said: 'The prayer of a man in congregation is higher than his prayer on his own by twenty-four or twenty-five levels}}
\hadithdefcmd{ibnmajah}{791}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَقَدْ هَمَمْتُ أَنْ آمُرَ بِالصَّلاَةِ فَتُقَامَ ثُمَّ آمُرَ رَجُلاً فَيُصَلِّيَ بِالنَّاسِ ثُمَّ أَنْطَلِقَ بِرِجَالٍ مَعَهُمْ حُزَمٌ مِنْ حَطَبٍ إِلَى قَوْمٍ لاَ يَشْهَدُونَ الصَّلاَةَ فَأُحَرِّقَ عَلَيْهِمْ بُيُوتَهُمْ بِالنَّارِ ‏"‏ ‏.‏\hadithno{791}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'I was thinking of commanding that the call to prayer be given, then I would tell a man to lead the people in prayer, then I would go out with some other men carrying bundles of wood, and go to people who do not attend the prayer, and burn their houses down around them}}
\hadithdefcmd{ibnmajah}{792}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ زَائِدَةَ، عَنْ عَاصِمٍ، عَنْ أَبِي رَزِينٍ، عَنِ ابْنِ أُمِّ مَكْتُومٍ، قَالَ قُلْتُ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ إِنِّي كَبِيرٌ ضَرِيرٌ شَاسِعُ الدَّارِ وَلَيْسَ لِي قَائِدٌ يُلاَوِمُنِي فَهَلْ تَجِدُ لِي مِنْ رُخْصَةٍ قَالَ ‏"‏ هَلْ تَسْمَعُ النِّدَاءَ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ مَا أَجِدُ لَكَ رُخْصَةً ‏"‏ ‏.‏\hadithno{792}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn Umm Maktum said:"I said to the Prophet: 'I am an old man and blind; my house is far away, and I have no one to lead me. Is there any concession (for me not to have to attend the prayer in the mosque)?' He said: 'Can you hear the call?' I said: 'Yes.' He said: 'Then I do not find any concession for you}}
\hadithdefcmd{ibnmajah}{793}{حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ بَيَانٍ الْوَاسِطِيُّ، أَنْبَأَنَا هُشَيْمٌ، عَنْ شُعْبَةَ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ سَمِعَ النِّدَاءَ فَلَمْ يَأْتِهِ فَلاَ صَلاَةَ لَهُ إِلاَّ مِنْ عُذْرٍ ‏"‏ ‏.‏\hadithno{793}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that:The Prophet said: "Whoever hears the call and does not come, his prayer is not valid, except for those who have an excuse}}
\hadithdefcmd{ibnmajah}{794}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ الدَّسْتَوَائِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنِ الْحَكَمِ بْنِ مِينَاءَ، أَخْبَرَنِي ابْنُ عَبَّاسٍ، وَابْنُ، عُمَرَ أَنَّهُمَا سَمِعَا النَّبِيَّ ـ صلى الله عليه وسلم ـ يَقُولُ عَلَى أَعْوَادِهِ ‏ "‏ لَيَنْتَهِيَنَّ أَقْوَامٌ عَنْ وَدْعِهِمُ الْجَمَاعَاتِ أَوْ لَيَخْتِمَنَّ اللَّهُ عَلَى قُلُوبِهِمْ ثُمَّ لَيَكُونُنَّ مِنَ الْغَافِلِينَ ‏"‏ ‏.‏\hadithno{794}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ibn 'Abbas and Ibn 'Umar narrated that:They heard the Prophet say on his pulpit: "People should desist from failing to attend the congregations, otherwise Allah will seal their hearts, and they will be among the negligent}}
\hadithdefcmd{ibnmajah}{795}{حَدَّثَنَا عُثْمَانُ بْنُ إِسْمَاعِيلَ الْهُذَلِيُّ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنِ الزِّبْرِقَانِ بْنِ عَمْرٍو الضَّمْرِيِّ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَيَنْتَهِيَنَّ رِجَالٌ عَنْ تَرْكِ الْجَمَاعَةِ أَوْ لأُحَرِّقَنَّ بُيُوتَهُمْ ‏"‏ ‏.‏\hadithno{795}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Usamah bin Zaid said:"The Messenger of Allah said: 'Let men desist from failing to attend the congregation, otherwise I will burn their houses down}}
\hadithdefcmd{ibnmajah}{796}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، حَدَّثَنِي مُحَمَّدُ بْنُ إِبْرَاهِيمَ التَّيْمِيُّ، حَدَّثَنِي عِيسَى بْنُ طَلْحَةَ، حَدَّثَتْنِي عَائِشَةُ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَوْ يَعْلَمُ النَّاسُ مَا فِي صَلاَةِ الْعِشَاءِ وَصَلاَةِ الْفَجْرِ لأَتَوْهُمَا وَلَوْ حَبْوًا ‏"‏ ‏.‏\hadithno{796}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Aishah said:"The Messenger of Allah said: 'If the people knew what (reward) there is in the 'Isha' prayer and fajr prayer, they would come even if they had to crawl}}
\hadithdefcmd{ibnmajah}{797}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، أَنْبَأَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ أَثْقَلَ الصَّلاَةِ عَلَى الْمُنَافِقِينَ صَلاَةُ الْعِشَاءِ وَصَلاَةُ الْفَجْرِ وَلَوْ يَعْلَمُونَ مَا فِيهِمَا لأَتَوْهُمَا وَلَوْ حَبْوًا ‏"‏ ‏.‏\hadithno{797}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'The most burdensome prayers for the hypocrites are the 'Isha' prayer and the Fajr prayer. If only they knew what (reward) there is in them, they would come to them even if they had to crawl}}
\hadithdefcmd{ibnmajah}{798}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ عُمَارَةَ بْنِ غَزِيَّةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهُ كَانَ يَقُولُ ‏ "‏ مَنْ صَلَّى فِي مَسْجِدٍ جَمَاعَةً أَرْبَعِينَ لَيْلَةً لاَ تَفُوتُهُ الرَّكْعَةُ الأُولَى مِنْ صَلاَةِ الْعِشَاءِ كَتَبَ اللَّهُ لَهُ بِهَا عِتْقًا مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{798}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Umar bin Khattab that:The Prophet used to say: "Whoever performs prayer in congregation at the mosque for forty nights, never missing the first Rak'ah of the 'Isha' prayer, Allah will thereby decree for him salvation from the Fire}}
\hadithdefcmd{ibnmajah}{799}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ أَحَدَكُمْ إِذَا دَخَلَ الْمَسْجِدَ كَانَ فِي صَلاَةٍ مَا كَانَتِ الصَّلاَةُ تَحْبِسُهُ وَالْمَلاَئِكَةُ يُصَلُّونَ عَلَى أَحَدِكُمْ مَادَامَ فِي مَجْلِسِهِ الَّذِي صَلَّى فِيهِ يَقُولُونَ اللَّهُمَّ اغْفِرْ لَهُ اللَّهُمَّ ارْحَمْهُ اللَّهُمَّ تُبْ عَلَيْهِ مَا لَمْ يُحْدِثْ فِيهِ مَا لَمْ يُؤْذِ فِيهِ ‏"‏ ‏.‏\hadithno{799}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'When one of you enters the mosque, he is in a state of prayer, so long as the prayer keeps him there, and the angels will send prayer upon anyone of you so long as he remains in the place where he prayed, saying: "O Allah, forgive him; O Allah, have mercy on him; O Allah, accept his repentance," so long as he does not commit Hadath nor disturb anyone}}
\hadithdefcmd{ibnmajah}{800}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الْمَقْبُرِيِّ، عَنْ سَعِيدِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَا تَوَطَّنَ رَجُلٌ مُسْلِمٌ الْمَسَاجِدَ لِلصَّلاَةِ وَالذِّكْرِ إِلاَّ تَبَشْبَشَ اللَّهُ لَهُ كَمَا يَتَبَشْبَشُ أَهْلُ الْغَائِبِ بِغَائِبِهِمْ إِذَا قَدِمَ عَلَيْهِمْ ‏"‏ ‏.‏\hadithno{800}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that:The Prophet said: "A muslim does not regularly attend the mosques to perform prayer and remember Allah, but Allah feels happy with him just as the family of one who is absent feels happy when he comes back to them}}
\hadithdefcmd{ibnmajah}{801}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الدَّارِمِيُّ، حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ أَبِي أَيُّوبَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ صَلَّيْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ الْمَغْرِبَ فَرَجَعَ مَنْ رَجَعَ وَعَقَّبَ مَنْ عَقَّبَ فَجَاءَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مُسْرِعًا قَدْ حَفَزَهُ النَّفَسُ و قَدْ حَسَرَ عَنْ رُكْبَتَيْهِ فَقَالَ ‏ "‏ أَبْشِرُوا هَذَا رَبُّكُمْ قَدْ فَتَحَ بَابًا مِنْ أَبْوَابِ السَّمَاءِ يُبَاهِي بِكُمُ الْمَلاَئِكَةَ يَقُولُ انْظُرُوا إِلَى عِبَادِي قَدْ قَضَوْا فَرِيضَةً وَهُمْ يَنْتَظِرُونَ أُخْرَى ‏"‏ ‏.‏\hadithno{801}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Abdullah bin 'Amr said:"We performed the Maghrib (prayer) with the Messenger of Allah, then those who went back went back, and those who stayed, stayed. Then the Messenger of Allah came back in a hurry, out of breath, with his garment pulled up to his knees, and said: 'Be of good cheer, for your Lord has opened one of the gates of heaven and is boasting of you before the angels, saying: "Look at My slaves; they have fulfilled one obligatory duty and are awaiting another}}
\hadithdefcmd{ibnmajah}{802}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا رِشْدِينُ بْنُ سَعْدٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ دَرَّاجٍ، عَنْ أَبِي الْهَيْثَمِ، عَنْ أَبِي سَعِيدٍ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ إِذَا رَأَيْتُمُ الرَّجُلَ يَعْتَادُ الْمَسَاجِدَ فَاشْهَدُوا لَهُ بِالإِيمَانِ قَالَ اللَّهُ تَعَالَى ‏\{إِنَّمَا يَعْمُرُ مَسَاجِدَ اللَّهِ مَنْ آمَنَ بِاللَّهِ\}‏ الآيَةَ ‏.‏\hadithno{802}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Sa'eed that:The Messenger of Allah said: "If you see a man frequenting the mosques, then bear witness to his faith. Allah says: 'The mosques of Allah shall be maintained only by those who believe in Allah and the Last Day. [At-Taubah:]}}
